/************************************************************************************/
/* Copyright (c) 2001, Analog Devices Inc., All Rights Reserved			    */
/*										    */
/* Hardware.h									    */	
/*										    */
/* Holds our Hardware structure definition.					    */	
/*										    */
/* This file is part of the "ADI USB ADSL Driver for Linux".			    */	
/*										    */
/* "ADI USB ADSL Driver for Linux" is free software; you can redistribute it 	    */
/* and/or modify it under the terms of the GNU General Public License as 	    */
/* published by the Free Software Foundation; either version 2 of the License,      */
/* or (at your option) any later version.					    */
/*										    */
/* "ADI USB ADSL Driver for Linux" is distributed in the hope that it will be       */
/* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of	    */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the		    */
/* GNU General Public License for more details.					    */	
/*										    */	
/* You should have received a copy of the GNU General Public License		    */
/* along with "ADI USB ADSL Driver for Linux"; if not, write to the Free Software   */ 
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA        */
/************************************************************************************/

#ifndef HARDWARE_H
#define HARDWARE_H


#include <linux/wait.h> 					//



typedef struct
{
    /*Holds USB device information (dev, interfaces, pipes, etc.)*/
    struct usb_device *usbdev;

    /*URBs allocated for this device*/
    urb_t urbInt;
    urb_t urbIdma;
    urb_t urbRead[INCOMING_Q_SIZE];
    urb_t urbWrite;
    urb_t urbOAMWrite;
    urb_t *pUrbReadIso[INCOMING_Q_SIZE];

    /*Info for when we're using ISO for receive*/
    UInt32 IsoPipeSize;
    UInt32 IsoFramesPerUrb;

    /*Device's endpoints*/
    UInt32 pipeIntIn;
    UInt32 pipeBulkIdmaOut;
    UInt32 pipeBulkDataOut;
    UInt32 pipeBulkDataIn;
    UInt32 pipeIsoDataIn;

    /*Data allocated at startup*/
    CDC_NOTIFY *pInterruptData;
    void       *pIncomingData[INCOMING_Q_SIZE];
    void       *pReadyData;
    void       *pOutgoingData;

    /**************************************************************************/ 
    /* MacOS is asyncronous for reads - we tell it there's data ready, then he*/ 
    /* reads it when he's ready. This forced us to queue incoming packets.    */
    /* Linux is much simpler - when we've got data - we send it to the stack. */
    /* So, we don't have to keep an incoming queue. To keep from modifying the*/
    /* Uni code too much, we alloc a static struct here			      */	
    /**************************************************************************/ 
    ETHERNET_PACKET_BUFFER ReassemblyBuffer;
    /****************************************************************************/ 
    /* The same is true with writes - in Mac land we had to queue writes, 'cause*/
    /* they came in from the OS faster than we could send them out over usb.    */
    /* In linux, we can stop the OS from sending us packets until we're done    */
    /* sending the current one, so we don't need to manage a send queue either  */
    /****************************************************************************/ 
    OUTGOING_BUFFER SegmentationBuffer;

    /*Modem state machine info*/
    AdiMSM      AdiModemSm;

    /*Raw DSP code read from .bnm file(s)*/
    BUFFER      DspCode;

    /*DSP code info*/
    UInt8      *pDsp;
    IDMAPage    MainPage;
    IDMAPage   *SwapPages;
    UInt32      SwapPageCount;
    UInt32      IDMAStart;

    /*URB queues*/
    QHdr    CtrlUrbFreeQ;   // queue of free control urb queue buffers
    QHdr    CtrlUrbPendQ;   // queue of pending control urbs

    /*Kernel timer(s)*/
    struct timer_list CtrlUrbQueueTimer;

    /****************************************************************************/ 
    /* The Darwin kernel makes us keep track of the size of our memory allocs   */
    /* so we'll just keep some alloc lists to use for freeing so the code	*/
    /* that uses the pointers doesn't have to change				*/
    /****************************************************************************/ 
    UInt32      DspAllocCount;
    BUFFER      DspAllocs[kMAX_DSP_ALLOCS];

    /*Misc data*/
    Bool        IsOpen;
    Bool        IsReading;
#ifdef DELAY_ISO_STARTUP
    Bool        IsReadPipeStarted;
#endif
    UInt32      MpoaMode;
    UInt8       MAC[ETH_LENGTH_OF_ADDRESS];
    Bool        MonitoringApp;

    /*Linux data*/
    struct net_device *pLinuxNet;
    struct net_device_stats LinuxStats;

    /*Statistics*/
    UInt32      Statistics[STAT_COUNT];

    /*ATM data*/
    ATMVC       Vc;

    /*DriverOptions*/
    DriverOption *pDriverOptions;

   CmvMsg *pDriverCMVs;

     int        AdiApiRWPending;                // Flag Shows if API CMV is pending	//
   //                                           // Used in Interrupt routine to 	//	
   //                                           // distinguish between User CMV Reply	//
   //                                           // and driver CMV replies         	//
   //						//					//
     int        APICmvError;                    // Shows Error in CMV Reply		//
   //						//					//
     wait_queue_head_t wq,wq2,wq4;		// Wait queues:				//
   //						// wq: CMV Pendinf wait queue		//
   //						// wq2: 200ms between CMV wait queue	//
   //						// wq3: 5ms after CMV wait queue	//
   //						// wq4: Read Dsp Memory wait queue	//
   //						//					//
     UInt16     ApiCmvRaw[kCMV_DATA_WORDS];	// 8 word encoded CMV packet    	//
   //						//					//
     UInt32     ApiCmvData;			// 32 bit CMV data			//
   //						//					//
     struct     semaphore sem;			// semaphore for controling multi 	//
   //						// process access to modem		//
   //						//					//
     int        UserCmvApiAcceptable; 		// Flag shows whether boot time has 	//
   //						// passed and User cmv is allowed	//
   //						//					//
     spinlock_t ApiLock;			// spin lock to control outboundpending	//
   //						// flag in interrupt handler		//
   //						//					//
     MsgQueue   Queue;              		// Message queue used to queue user CMV //
   // 						// or Driver cmv requests when other is //
   // 						// pending				//
   //						//					//
     long       LastApiTime;			// Last jiffies that one CMV was sent	//
   //						// to modem. used to determine whether  //
   //						// it is too soon to send next cmv or   //
   //						// not(200ms wait between CMVs)		//
   //						//					//
     int        ApiTestReq; 			// Flag shows if modem is booting to go	//
   //						// to test signal state.		//
   //						//					//
     int        BlockSwapReq;			// Flag shows if during booting for test//
   //						// we've got the swap page number 1.    //
   //						//					//
     UInt8      DspMemData;			// 8 bit character to read/write dsp 	//
   //						// memory				//
     int        PrevState;			// Variable holds previous state of     //
   // 						// state machine handler. used when     //
   //  						// state machine is disbaled and then 	//
   //						// enabled.				//
   //						//					//
     int        GPRegister;			// General Purpose register. bit 1 shows//
   //						// state machine is disabled (1) or 	//
   //						// enabled(0)				//
     long       InitTime;			// Shows the jiffies at the probe time. //
   //						// used for determinig how much time is //
   //						// passed				// 
     int        BootState;			// Holds State of Boot Machine during   //
   //						// modem boot procedure			//
   //						//					//					
     struct timer_list BootTimer;		// Timer that handles delays between 	//
   //						// steps of boot procedure		//


    // State variables used for OAM stuff
    Boolean     OAMState_TimerOn;
    Boolean     OAMState_SendingCC;
    Boolean     OAMState_ReceiveCC;
    Boolean     OAMState_AIS;
    UInt32      OAMState_CCSink;
    UInt8       OAMCell[ATM_CELL_SIZE*2];
    UInt8       *pOAMCell;			
    UInt8       OAMCellHeader[ATM_CELL_HEADER_SIZE*2];
	struct timer_list OAMTimer;

    Boolean     FakePacketReady;
    UInt32      FakePacketSize;
    UInt8       *pPacket; // [ETHERNET_MAX_PACKET_SIZE];
    ETHERNET_MAC_HEADER FakeHeader;

    int booter_thread_pid;
	Boolean		LowRateFlag; //Low bit Rate: 04042003
	Boolean		UnplugFlag;  //04152003

} Hardware;

/*Comment out this line to build for 930 hardware*/
#define EAGLE 1

#endif /*HARDWARE_H*/

