/*************************************************************************************/
/* Macros.h									     */	
/*										     */	
/* Various macros used throughout the code					     */	
/*										     */	
/* This file is part of the "ADI USB ADSL Driver for Linux".			     */	
/*										     */	
/* "ADI USB ADSL Driver for Linux" is free software; you can redistribute it         */
/* and/or modify it under the terms of the GNU General Public License as             */
/* published by the Free Software Foundation; either version 2 of the License,       */
/* or (at your option) any later version.					     */
/*										     */
/* "ADI USB ADSL Driver for Linux" is distributed in the hope that it will be        */
/* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of	     */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the		     */	
/* GNU General Public License for more details.					     */	
/*										     */	
/* You should have received a copy of the GNU General Public License		     */	
/* along with "ADI USB ADSL Driver for Linux"; if not, write to the Free Software    */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA	     */
/*************************************************************************************/

#ifndef MACROS_H
#define MACROS_H

/*HSTOLE - host short to little-endian (for things the firmware expects in Intel format)*/
/*Since this is for x86 Linux - we're already in LE format :)*/
#define HSTOLE( _short ) _short
/*HSTOBE - host short to big-endian (for outgoing ATM cell fields)*/
#define HSTOBE( _short ) \
	( (((_short) & 0x00FF)<<8) | (((_short) & 0xFF00)>>8))
/*HLTOBE - host long to big-endian (for outgoing ATM cell fields)*/
#define HLTOBE( _long ) \
    (((_long)&0x000000FF)<<24) | (((_long)&0x0000FF00)<<8) | \
    (((_long)&0x00FF0000)>>8)  | (((_long)&0xFF000000)>>24)
/*BETOHS - big-endian to host short*/
#define BETOHS( _short ) \
    ((((_short) & 0x00FF)<<8) | (((_short) & 0xFF00)>>8))
/*BETOHL - big-endian to host long*/
#define BETOHL( _long ) \
    (((_long)&0x000000FF)<<24) | (((_long)&0x0000FF00)<<8) | \
    (((_long)&0x00FF0000)>>8)  | (((_long)&0xFF000000)>>24)

/*Memory macros*/
#define COPY_MEM(src, dst, len) memcpy(dst, src, len)
#define ZERO_MEM(dst, len) memset(dst, 0, len)

/*quasi-function to obtain current status of SM*/
#define GetOpStatusSM(_ADAPTER_) ((_ADAPTER_->CurrentAdiState&STATE_OPERATIONAL)!=0)

/*Macro for cancelling the StateMachine timer*/
#define CancelTimerSM(_ADAPTER_) SetTimerInterval(_ADAPTER_,0)

/*quasi-function to signal beginning of SM reset*/
/*actual processing would happen later, on next refresh*/
#define ResetModemSM(_ADAPTER_) if(_ADAPTER_->CurrentAdiState!=STATE_STALLED_FOREVER) \
                                { (_ADAPTER_->CurrentAdiState=STATE_HARD_RESET_INITIATE); }

#define MSEC_TO_JIFFIES(_msec_) ((HZ*_msec_)/1000)

#define ADI_Min(X, Y)  ((X) < (Y) ? (X) : (Y))
#define ADI_Max(X, Y)  ((X) > (Y) ? (X) : (Y))

#endif /*MACROS_H*/

