/*********************************************************************************/
/*										 */
/* Protos.h									 */
/*										 */
/* Prototypes for routines exported for use from Adiutil			 */
/*										 */
/* This file is part of the "ADI USB ADSL Driver for Linux".			 */
/*										 */
/* "ADI USB ADSL Driver for Linux" is free software; you can redistribute it     */
/* and/or modify it under the terms of the GNU General Public License as 	 */
/* published by the Free Software Foundation; either version 2 of the License,   */
/* or (at your option) any later version.					 */
/*										 */
/* "ADI USB ADSL Driver for Linux" is distributed in the hope that it will be    */
/* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of	 */	
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the		 */
/* GNU General Public License for more details.					 */
/*										 */ 
/* You should have received a copy of the GNU General Public License		 */
/* along with "ADI USB ADSL Driver for Linux"; if not, write to the Free Software*/
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     */
/*********************************************************************************/

#ifndef PROTOS_H
#define PROTOS_H

/*********************************************************************************/
/* Dsp.c									 */
/*********************************************************************************/
Boolean DspFoodProcessor(Hardware *pHw);
void FreeDspData(Hardware *pHw);

/*********************************************************************************/
/* Boot.c									 */
/*********************************************************************************/
void BootTheModem(Hardware *pHw, Bool Rebooting);
void IdmaUploadSwapPage(Hardware *pHw, UInt16 SwapInfo);

void SoftRestart(Hardware *pHw);    


/*********************************************************************************/
/* Util.c									 */
/*********************************************************************************/

int loadUsbFirmware(Hardware *pHw,UInt32 pid);

int EZUSBWrite(Hardware *pHw, UInt16 EZUSBAddress, UInt16 count, UInt8 writeBuffer[]);
int AllocQueuedBuffers(Hardware *pHw, UInt32 BufCount, UInt32 BufSize, UInt32 DataSize, QHdr *pQ, Boolean SetQueueEntry);
void DeAllocQueuedBuffers(QHdr *pQ);
QHdr *GetBufferFromQ(QHdr *pQ);
void PutBufferInQ(GENERIC_BUFFER *pBuf, QHdr *pQ);
void WriteDspMsg(Hardware *pHw, UInt16 Addr, UInt16 *pData);
int AdiCustomWrite(Hardware *pHw, UInt32 Cmd, UInt32 Index, UInt32 Count, UInt8 *pData);
int AdiCustomWriteIm(Hardware *pHw, UInt32 Cmd, UInt32 Index, UInt32 Count, UInt8 *pData);
void CtrlUrbQueueWatcher(unsigned long ptr);
void GetMacAddress(Hardware *pHw);


void MemReadCompletion(struct urb *urb);					//
void ReadDspMem(Hardware *pHw, UInt16 Addr, UInt8 *pData);			//	
void WriteDspMem(Hardware *pHw, UInt16 Addr, UInt8 *pData);			//



/*********************************************************************************/
/* Msg.c									 */
/*********************************************************************************/
void MsgInitialize(Hardware *pHw);
UInt32  MsgDecode(mp_message *MsgDrv, UInt16 MsgRaw[8]);
void MsgSend(Hardware *pHw, UInt16 *Packet);


void UserMsgSend(Hardware *pHw, UInt16 *Packet);				//


/*********************************************************************************/
/* Me.c										 */
/*********************************************************************************/
void ProcessIncomingCmv(Hardware *pHw, UInt16 *pMsg);
int SetTimerInterval( Hardware*, int Duration );
void WatchdogTimer(unsigned long ptr);
int AdjustTimerInterval(Hardware* pHw, int reqDelay);

/*********************************************************************************/
/* Crc.c									 */
/*********************************************************************************/
void CrcGenerateTable(void);
UInt32 CrcCalculate(UInt8 *Cell, UInt32 Length, UInt32 Crc);

/*********************************************************************************/
/* Mpoa.c									 */
/*********************************************************************************/
void MpoaInitialize(Hardware *pHw, UInt32 MpoaMode);
void MpoaProcessReceivedPdu(Hardware *pHw, ETHERNET_PACKET_BUFFER *pBuf);
void EthernetArpReply(Hardware *pHw, UInt8 *pBuf, UInt32 PacketSize);	

/*********************************************************************************/
/* Uni.c							                 */
/*********************************************************************************/
void UniEstablishVc(Hardware *pHw, UInt8 *pEncapHdr, UInt32 EncapSize);
int UniProcessOutboundPdu(Hardware *pHw, UInt8 *pPacket, UInt32 PacketSize);
ATMVC *UniLookupVc(Hardware *pHw, UInt32 VpiVci);
int UniProcessInboundData(Hardware *pHw, UInt8 *pData, UInt32 DataLength);

/*********************************************************************************/
/* Sar.c									 */
/*********************************************************************************/
void Aal5InitSegmenter(SarSegmenter *pSar, UInt32 PduLength, UInt8 *pOutputBuffer, UInt8 *pCellHeader);
void Aal5Segment(SarSegmenter *pSar, UInt8 *pInputBuffer, UInt32 InputLength);
void Aal5InitReassembler(SarReassembler *pSar, ETHERNET_PACKET_BUFFER *pBuf);
UInt16 Aal5WritePadAndTrailer(SarSegmenter *pSar, UInt8 CpcsUu, UInt8 Cpi);
void Aal5ReassembleNonFinalCell(SarReassembler *pSar, UInt8 *pCellPayload);
void Aal5ReassembleFinalCell(SarReassembler *pSar, UInt8 *pCellPayload);

/*********************************************************************************/
/* Pipes.c									 */
/*********************************************************************************/
void StartReadPipe(Hardware *pHw);
void StopReadPipe(Hardware *pHw);
void ReadSendItUp(Hardware *pHw, ETHERNET_PACKET_BUFFER *pPacket);
int WriteAtmData(Hardware *pHw);


/*********************************************************************************/	//
/* Sm.c									 */		//
/*********************************************************************************/	//
void ModemSM(UInt16 uEventCode, Hardware *pHw, void *pData);				//


/*********************************************************************************/
/* Zaps.c									 */
/*********************************************************************************/
Boolean DoZap(UInt32 myModule, UInt32 myLevel);

#endif /*PROTOS_H*/
