/**************************************************************************************/
/*										      */
/* Zaps.h									      */
/*										      */
/* ZAP* macro definitions (similar to DBGPRINT macros from NDIS code)		      */	
/*										      */
/* This file is part of the "ADI USB ADSL Driver for Linux".			      */
/*										      */
/* "ADI USB ADSL Driver for Linux" is free software; you can redistribute it 	      */
/* and/or modify it under the terms of the GNU General Public License as 	      */
/* published by the Free Software Foundation; either version 2 of the License, 	      */
/* or (at your option) any later version.					      */
/*										      */
/* "ADI USB ADSL Driver for Linux" is distributed in the hope that it will be 	      */
/* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of	      */	
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the		      */
/* GNU General Public License for more details.					      */
/*										      */
/* You should have received a copy of the GNU General Public License		      */
/* along with "ADI USB ADSL Driver for Linux"; if not, write to the Free Software     */	
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA	      */	
/**************************************************************************************/

#ifndef ZAPS_H
#define ZAPS_H

/**************************************************************************************/
/* Zappable modules and levels							      */
/**************************************************************************************/

#define DEBUG_SAR       0x00000001
#define DEBUG_UNI       0x00000002
#define DEBUG_MPOA      0x00000004
#define DEBUG_INIT      0x00000008
#define DEBUG_FIRMWARE  0x00000010
#define DEBUG_PIPES     0x00000020
#define DEBUG_IDMA      0x00000040
#define DEBUG_ENET      0x00000080
#define DEBUG_BOOT      0x00000100
#define DEBUG_UTILS     0x00000200
#define DEBUG_MSG       0x00000400
#define DEBUG_SM        0x00000800
#define DEBUG_READ      0x00001000
#define DEBUG_WRITE     0x00002000
#define DEBUG_INTS      0x00004000
#define DEBUG_CRC       0x00008000
#define DEBUG_POWER     0x00010000
#define DEBUG_CONFIG    0x00020000
/* modules added for OSX*/
#define DEBUG_MISC      0x00040000
#define DEBUG_START     0x00080000
#define DEBUG_DSP       0x00100000
/* modules added for Linux*/
#define DEBUG_MEMORY    0x00200000
#define DEBUG_URB       0x00400000

/* OAM & ROUTED */
#define DEBUG_IOCTL     0x00800000 // ROUTED
#define DEBUG_OAM	0x01000000 // OAM
#define DEBUG_ROUTEIP	0x02000000 // ROUTED
#define DEBUG_FFD	0x04000000 // ROUTED

#define DEBUG_ENTRY     0x00000001
#define DEBUG_EXIT      0x00000002
#define DEBUG_MEMCOPY   0x00000004
#define DEBUG_ATTN      0x00000008
#define DEBUG_ERROR     0x00000010
#define DEBUG_ERRORS    0x00000010
#define DEBUG_INFO      0x00000020
#define DEBUG_DATA      0x00000040

#define DEBUG_ALL       0xFFFFFFFF
#define DEBUG_NONE      0x00000000


#ifdef ZAPS /* make sure ZAPS is defined to include ZAP output  */
            /* (eventually these will call routines in a Zaps.c)*/

#define ZAPIF( _Condition,  _Module, _Level, _Msg ) \
    if ((_Condition) && DoZap(_Module,_Level)) \
        printk _Msg;

#define ZAP(                _Module, _Level, _Msg ) \
    if (DoZap(_Module,_Level)) \
        printk _Msg;

#define Zap(                                 _Msg ) \
        printk _Msg;

#ifdef DANGER
/* special tool to trap early execution*/
#define TIME_TRAP(_delay_) { \
    Duration chk = _delay_; \
    Duration dur = InitTime(); \
    if( dur < chk ) Debugger(); \
    Zap(("\n #### Trap @%i passed; time is %i\n\n",chk,dur)); \
}
#endif

#else  /* no debug trace facilities*/
#define ZAPIF( _Condition,  _Module, _Level, _Msg )
#define ZAP(                _Module, _Level, _Msg )
#define Zap(                                 _Msg )
#define TIME_TRAP(_delay_)
#endif /* ZAPS*/

#endif /* ZAPS_H*/

