/*******************************************************************************/
/*									       */	
/* Copyright (c) 2002, Analog Devices Inc., All Rights Reserved		       */	
/*									       */	
/* Stuff.h								       */	
/*									       */
/* Miscellaneous stuff needed in the .c files of the application	       */
/* Much of this is required because of code that was used as-is from	       */
/* the MacOS9 project, or from the kernel driver code.			       */	
/*******************************************************************************/

/* We don't define ZAPS on purpose so we can do this:*/
#ifdef DEBUG
#define ZAP( _Module, _Level, _Msg) \
    printf _Msg;
#else
#define ZAP( _Module, _Level, _Msg)
#endif

#define UInt8                       unsigned char
#define UInt16                      unsigned short
#define UInt32                      unsigned int
#define Boolean                     unsigned int
#define OSStatus                    Boolean
#define FALSE                       0
#define false                       0
#define TRUE                        1
#define true                        1
#define ioErr                       1
#define noErr                       0

#define DSP_FIRMWARE_FILES          5
#define CFILE_ADSL_POTS_FIRMWARE0    "/etc/analog/rtbldep0.bnm"
#define CFILE_ADSL_POTS_FIRMWARE1    "/etc/analog/rtbldep1.bnm"
#define CFILE_ADSL_POTS_FIRMWARE2    "/etc/analog/rtbldep2.bnm"
#define CFILE_ADSL_POTS_FIRMWARE3    "/etc/analog/rtbldep3.bnm"
#define CFILE_ADSL_POTS_FIRMWARE4    "/etc/analog/rtbldep4.bnm"
#define CFILE_ADSL_ISDN_FIRMWARE0    "/etc/analog/rtbldei0.bnm"
#define CFILE_ADSL_ISDN_FIRMWARE1    "/etc/analog/rtbldei1.bnm"
#define CFILE_ADSL_ISDN_FIRMWARE2    "/etc/analog/rtbldei2.bnm"
#define CFILE_ADSL_ISDN_FIRMWARE3    "/etc/analog/rtbldei3.bnm"
#define CFILE_ADSL_ISDN_FIRMWARE4    "/etc/analog/rtbldei4.bnm"

#define USB_PATH                "/proc/bus/usb/"

#define IFNULL_RETURN_MEMERR(ptr,msg) \
    if (ptr == NULL) \
    { \
        ZAP(DEBUG_INIT, DEBUG_ERRORS, (msg)); \
        return ioErr; \
    }

#define GET_MEMORY(size) \
    malloc(size);

#define GET_BUFFER GET_MEMORY

#define FREE_BUFFER(ptr) \
    free(ptr);

/* Just a simple structure to hold firmware data read from a file*/
typedef struct
{
    UInt8   *pBits;
    UInt32  Size;
} Firmware;

typedef struct
{
    /* Firmware data read from external files*/
    Firmware    FPGAFirmware;
    Firmware    ADSLFirmware[DSP_FIRMWARE_FILES];

    /* DSP code info*/
    UInt8      *pDsp;
    UInt32     IDMAStart;
} Hardware;

#define MAX_OPTION_NAME_LENGTH      64
typedef struct
{
	char 	Name[MAX_OPTION_NAME_LENGTH];
	UInt32	Value;
} DriverOption;

typedef struct
{
      UInt16 Preamble;
      UInt16 Function;
      UInt16 Index;
      UInt8  SymAddrHiHi;
      UInt8  SymAddrHiLo;
      UInt8  SymAddrLoHi;
      UInt8  SymAddrLoLo;
      UInt16 Offset;
      UInt32 Data; 
} CmvMsg;

/* Device descriptor */
typedef struct {
	UInt8     bLength;
	UInt8     bDescriptorType;
	UInt16    bcdUSB;
	UInt8     bDeviceClass;
	UInt8     bDeviceSubClass;
	UInt8     bDeviceProtocol;
	UInt8     bMaxPacketSize0;
	UInt16    idVendor;
	UInt16    idProduct;
	UInt16    bcdDevice;
	UInt8     iManufacturer;
	UInt8     iProduct;
	UInt8     iSerialNumber;
	UInt8     bNumConfigurations;
} usb_device_descriptor;

UInt16 ModemType;
